@@ -25,6 +25,10 @@
 
 #include "albumsettings.moc"
 
+// Qt includes
+
+#include <QDBusInterface>
+
 // KDE includes
 
 #include <kconfig.h>
@@ -33,25 +37,23 @@
 #include <kglobal.h>
 #include <kconfiggroup.h>
 #include <kglobalsettings.h>
+#include <kstandarddirs.h>
 
 // LibKDcraw includes
 
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
-#if KDCRAW_VERSION < 0x000400
-#include <libkdcraw/dcrawbinary.h>
-#endif
-
 // Local includes
 
 #include "config-digikam.h"
-#include "thumbnailsize.h"
-#include "mimefilter.h"
-#include "databaseaccess.h"
 #include "albumdb.h"
+#include "databaseaccess.h"
+#include "databaseparameters.h"
 #include "imagefiltersettings.h"
 #include "imagesortsettings.h"
+#include "mimefilter.h"
+#include "thumbnailsize.h"
 
 namespace Digikam
 {
@@ -60,15 +62,12 @@ class AlbumSettingsPrivate
 {
 
 public:
-
     AlbumSettingsPrivate() :
         configGroupDefault("Album Settings"),
         configGroupExif("EXIF Settings"),
         configGroupMetadata("Metadata Settings"),
         configGroupNepomuk("Nepomuk Settings"),
         configGroupGeneral("General Settings"),
-
-        configDatabaseFilePathEntry("Database File Path"),
         configAlbumCollectionsEntry("Album Collections"),
         configAlbumSortOrderEntry("Album Sort Order"),
         configImageSortOrderEntry("Image Sort Order"),
@@ -136,7 +135,8 @@ public:
         configApplySidebarChangesDirectlyEntry("Apply Sidebar Changes Directly"),
         configScanAtStartEntry("Scan At Start"),
         configSyncNepomuktoDigikamEntry("Sync Nepomuk to Digikam"),
-        configSyncDigikamtoNepomukEntry("Sync Digikam to Nepomuk")
+        configSyncDigikamtoNepomukEntry("Sync Digikam to Nepomuk"),
+        configStringComparisonTypeEntry("String Comparison Type")
         {}
 
     const QString                       configGroupDefault;
@@ -145,7 +145,6 @@ public:
     const QString                       configGroupNepomuk;
     const QString                       configGroupGeneral;
 
-    const QString                       configDatabaseFilePathEntry;
     const QString                       configAlbumCollectionsEntry;
     const QString                       configAlbumSortOrderEntry;
     const QString                       configImageSortOrderEntry;
@@ -214,6 +213,7 @@ public:
     const QString                       configScanAtStartEntry;
     const QString                       configSyncNepomuktoDigikamEntry;
     const QString                       configSyncDigikamtoNepomukEntry;
+    const QString                       configStringComparisonTypeEntry;
 
     // start up setting
     bool                                showSplash;
@@ -302,7 +302,7 @@ public:
     QString                             currentTheme;
 
     // database settings
-    QString                             databaseFilePath;
+    DatabaseParameters                  databaseParams;
 
     // album settings
     QStringList                         albumCategoryNames;
@@ -323,6 +323,9 @@ public:
     // nepomuk settings
     bool                                syncToDigikam;
     bool                                syncToNepomuk;
+
+    //misc
+    AlbumSettings::StringComparisonType stringComparisonType;
 };
 
 class AlbumSettingsCreator { public: AlbumSettings object; };
@@ -438,6 +441,11 @@ void AlbumSettings::init()
 
     d->syncToDigikam                = false;
     d->syncToNepomuk                = false;
+
+    d->stringComparisonType         = AlbumSettings::Natural;
+
+    connect(this, SIGNAL(nepomukSettingsChanged()),
+            this, SLOT(applyNepomukSettings()));
 }
 
 void AlbumSettings::readSettings()
@@ -448,8 +456,6 @@ void AlbumSettings::readSettings()
 
     KConfigGroup group  = config->group(d->configGroupDefault);
 
-    d->databaseFilePath = group.readEntry(d->configDatabaseFilePathEntry, QString());
-
     QStringList collectionList = group.readEntry(d->configAlbumCollectionsEntry, QStringList());
     if (!collectionList.isEmpty())
     {
@@ -554,9 +560,12 @@ void AlbumSettings::readSettings()
     d->showPermanentDeleteDialog = group.readEntry(d->configShowPermanentDeleteDialogEntry,   true);
     d->sidebarApplyDirectly      = group.readEntry(d->configApplySidebarChangesDirectlyEntry, false);
     d->scanAtStart               = group.readEntry(d->configScanAtStartEntry,                 true);
+    d->stringComparisonType      = (StringComparisonType) group.readEntry(d->configStringComparisonTypeEntry, (int) Natural);
 
     // ---------------------------------------------------------------------
 
+    d->databaseParams.readFromConfig();
+
 #ifdef HAVE_NEPOMUK
 
     group = config->group(d->configGroupNepomuk);
@@ -579,7 +588,6 @@ void AlbumSettings::saveSettings()
 
     KConfigGroup group = config->group(d->configGroupDefault);
 
-    group.writeEntry(d->configDatabaseFilePathEntry,             d->databaseFilePath);
     group.writeEntry(d->configAlbumCollectionsEntry,             d->albumCategoryNames);
     group.writeEntry(d->configAlbumSortOrderEntry,               (int)d->albumSortOrder);
     group.writeEntry(d->configImageSortOrderEntry,               (int)d->imageSortOrder);
@@ -668,9 +676,12 @@ void AlbumSettings::saveSettings()
     group.writeEntry(d->configShowPermanentDeleteDialogEntry,   d->showPermanentDeleteDialog);
     group.writeEntry(d->configApplySidebarChangesDirectlyEntry, d->sidebarApplyDirectly);
     group.writeEntry(d->configScanAtStartEntry,                 d->scanAtStart);
+    group.writeEntry(d->configStringComparisonTypeEntry,        (int) d->stringComparisonType);
 
     // ---------------------------------------------------------------------
 
+    d->databaseParams.writeToConfig();
+
 #ifdef HAVE_NEPOMUK
 
     group = config->group(d->configGroupNepomuk);
@@ -690,12 +701,13 @@ void AlbumSettings::emitSetupChanged()
 
 QString AlbumSettings::getDatabaseFilePath() const
 {
-    return d->databaseFilePath;
+    return d->databaseParams.getDatabaseNameOrDir();
 }
 
 void AlbumSettings::setDatabaseFilePath(const QString& path)
 {
-    d->databaseFilePath = path;
+    d->databaseParams.setDatabasePath(path);
+    d->databaseParams.setThumbsDatabasePath(path);
 }
 
 void AlbumSettings::setShowSplashScreen(bool val)
@@ -825,14 +837,7 @@ QString AlbumSettings::getAudioFileFilter() const
 
 QString AlbumSettings::getRawFileFilter() const
 {
-    QStringList supportedRaws;
-#if KDCRAW_VERSION < 0x000400
-    if (KDcrawIface::DcrawBinary::instance()->versionIsRight())
-        supportedRaws = KDcrawIface::DcrawBinary::rawFilesList();
-#else
-    supportedRaws = KDcrawIface::KDcraw::rawFilesList();
-#endif
-
+    QStringList supportedRaws = KDcrawIface::KDcraw::rawFilesList();
     QStringList imageSettings;
     DatabaseAccess().db()->getFilterSettings(&imageSettings, 0, 0);
 
@@ -1517,5 +1522,140 @@ bool AlbumSettings::getSyncDigikamToNepomuk() const
     return d->syncToNepomuk;
 }
 
+DatabaseParameters AlbumSettings::getDatabaseParameters() const
+{
+    return d->databaseParams;
+}
+
+void AlbumSettings::setDatabaseParameters(const DatabaseParameters& params)
+{
+    d->databaseParams = params;
+}
+
+QString AlbumSettings::getDatabaseType() const
+{
+    return d->databaseParams.databaseType;
+}
+
+void AlbumSettings::setDatabaseType(const QString &databaseType)
+{
+    d->databaseParams.databaseType = databaseType;
+}
+
+QString AlbumSettings::getDatabaseConnectoptions() const
+{
+    return d->databaseParams.connectOptions;
+}
+
+QString AlbumSettings::getDatabaseName() const
+{
+    return d->databaseParams.databaseName;
+}
+
+QString AlbumSettings::getDatabaseNameThumbnails() const
+{
+    return d->databaseParams.databaseNameThumbnails;
+}
+
+QString AlbumSettings::getDatabaseHostName() const
+{
+    return d->databaseParams.hostName;
+}
+
+QString AlbumSettings::getDatabasePassword() const
+{
+    return d->databaseParams.password;
+}
+
+int AlbumSettings::getDatabasePort() const
+{
+    return d->databaseParams.port;
+}
+
+QString AlbumSettings::getDatabaseUserName() const
+{
+    return d->databaseParams.userName;
+}
+
+bool AlbumSettings::getInternalDatabaseServer() const
+{
+    return d->databaseParams.internalServer;
+}
+
+void AlbumSettings::setDatabaseConnectoptions(const QString &connectoptions)
+{
+    d->databaseParams.connectOptions = connectoptions;
+}
+
+void AlbumSettings::setDatabaseName(const QString &databaseName)
+{
+    d->databaseParams.databaseName = databaseName;
+}
+
+void AlbumSettings::setDatabaseNameThumbnails(const QString &databaseNameThumbnails)
+{
+    d->databaseParams.databaseNameThumbnails = databaseNameThumbnails;
+}
+
+void AlbumSettings::setDatabaseHostName(const QString &hostName)
+{
+    d->databaseParams.hostName = hostName;
+}
+
+void AlbumSettings::setDatabasePassword(const QString &password)
+{
+    d->databaseParams.password = password;
+}
+
+void AlbumSettings::setDatabasePort(int port)
+{
+    d->databaseParams.port = port;
+}
+
+void AlbumSettings::setDatabaseUserName(const QString &userName)
+{
+    d->databaseParams.userName = userName;
+}
+
+void AlbumSettings::setInternalDatabaseServer(const bool useInternalDBServer)
+{
+    d->databaseParams.internalServer = useInternalDBServer;
+}
+
+void AlbumSettings::setStringComparisonType(AlbumSettings::StringComparisonType val)
+{
+    d->stringComparisonType = val;
+}
+
+AlbumSettings::StringComparisonType AlbumSettings::getStringComparisonType() const
+{
+    return d->stringComparisonType;
+}
+
+void AlbumSettings::applyNepomukSettings() const
+{
+#ifdef HAVE_NEPOMUK
+    QDBusInterface interface("org.kde.nepomuk.services.digikamnepomukservice",
+                              "/digikamnepomukservice", "org.kde.digikam.DigikamNepomukService");
+    if (interface.isValid())
+    {
+        interface.call(QDBus::NoBlock, "enableSyncToDigikam", d->syncToDigikam);
+        interface.call(QDBus::NoBlock, "enableSyncToNepomuk", d->syncToNepomuk);
+    }
+#endif // HAVE_NEPOMUK
+}
+
+void AlbumSettings::triggerResyncWithNepomuk() const
+{
+#ifdef HAVE_NEPOMUK
+    QDBusInterface interface("org.kde.nepomuk.services.digikamnepomukservice",
+                              "/digikamnepomukservice", "org.kde.digikam.DigikamNepomukService");
+    if (interface.isValid())
+    {
+        interface.call(QDBus::NoBlock, "triggerResync");
+    }
+#endif // HAVE_NEPOMUK
+}
+
 
 }  // namespace Digikam
