@@ -165,7 +165,7 @@ bool RatingWidget::hasFading() const
 void RatingWidget::setFadingValue(int value)
 {
     d->fadingValue = value;
-    if (d->fadingValue >= 255)
+    if (d->fadingValue >= 255 && d->fadingTimeLine)
     {
         d->fadingTimeLine->stop();
     }
@@ -182,6 +182,11 @@ void RatingWidget::setVisible(bool visible)
         stopFading();
 }
 
+int RatingWidget::maximumVisibleWidth() const
+{
+    return RatingMax * (d->disPixmap.width()+1);
+}
+
 void RatingWidget::startFading()
 {
     if (!hasFading()) return;
@@ -206,6 +211,11 @@ void RatingWidget::stopFading()
     update();
 }
 
+void RatingWidget::setVisibleImmediately()
+{
+    setFadingValue(255);
+}
+
 QPixmap RatingWidget::starPixmapDisabled() const
 {
     return d->disPixmap;
