@@ -97,53 +97,53 @@ public:
     }
 
     // Golden guide types.
-    bool                 drawGoldenSection;
-    bool                 drawGoldenSpiralSection;
-    bool                 drawGoldenSpiral;
-    bool                 drawGoldenTriangle;
+    bool        drawGoldenSection;
+    bool        drawGoldenSpiralSection;
+    bool        drawGoldenSpiral;
+    bool        drawGoldenTriangle;
 
     // Golden guide translations.
-    bool                 flipHorGoldenGuide;
-    bool                 flipVerGoldenGuide;
+    bool        flipHorGoldenGuide;
+    bool        flipVerGoldenGuide;
 
-    bool                 moving;
-    bool                 autoOrientation;
-    bool                 preciseCrop;
+    bool        moving;
+    bool        autoOrientation;
+    bool        preciseCrop;
 
-    bool                 isDrawingSelection;
+    bool        isDrawingSelection;
 
-    int                  guideLinesType;
-    int                  guideSize;
+    int         guideLinesType;
+    int         guideSize;
 
-    int                  currentAspectRatioType;
-    int                  currentResizing;
-    int                  currentOrientation;
+    int         currentAspectRatioType;
+    int         currentResizing;
+    int         currentOrientation;
 
-    float                currentWidthRatioValue;
-    float                currentHeightRatioValue;
+    float       currentWidthRatioValue;
+    float       currentHeightRatioValue;
 
-    QPoint               lastPos;
+    QPoint      lastPos;
 
-    QRect                rect;
-    QRect                image;                   // Real image dimension.
-    QRect                regionSelection;         // Real size image selection.
-    QRect                localRegionSelection;    // Local size selection.
+    QRect       rect;
+    QRect       image;                   // Real image dimension.
+    QRect       regionSelection;         // Real size image selection.
+    QRect       localRegionSelection;    // Local size selection.
 
     // Draggable local region selection corners.
-    QRect                localTopLeftCorner;
-    QRect                localBottomLeftCorner;
-    QRect                localTopRightCorner;
-    QRect                localBottomRightCorner;
+    QRect       localTopLeftCorner;
+    QRect       localBottomLeftCorner;
+    QRect       localTopRightCorner;
+    QRect       localBottomRightCorner;
 
-    QPixmap*             pixmap;
-    QPixmap              grayOverLay;
-    QPixmap              previewPixmap;
+    QPixmap*    pixmap;
+    QPixmap     grayOverLay;
+    QPixmap     previewPixmap;
 
-    QColor               guideColor;
+    QColor      guideColor;
 
-    Digikam::DImg        preview;
+    DImg        preview;
 
-    Digikam::ImageIface* iface;
+    ImageIface* iface;
 };
 
 ImageSelectionWidget::ImageSelectionWidget(int w, int h, QWidget *parent)
@@ -186,26 +186,27 @@ void ImageSelectionWidget::setup(int w, int h,
     setMouseTracking(true);
     setAttribute(Qt::WA_DeleteOnClose);
 
-    d->iface        = new Digikam::ImageIface(w, h);
+    d->iface        = new ImageIface(w, h);
     uchar *data     = d->iface->getPreviewImage();
     int width       = d->iface->previewWidth();
     int height      = d->iface->previewHeight();
     bool sixteenBit = d->iface->previewSixteenBit();
     bool hasAlpha   = d->iface->previewHasAlpha();
-    d->preview      = Digikam::DImg(width, height, sixteenBit, hasAlpha, data);
-    delete [] data;
+    d->preview      = DImg(width, height, sixteenBit, hasAlpha, data);
+    d->preview.setIccProfile( d->iface->getOriginalImg()->getIccProfile() );
     d->preview.convertToEightBit();
-    d->pixmap  = new QPixmap(w, h);
+    delete [] data;
 
-    d->image = QRect(0, 0, d->iface->originalWidth(), d->iface->originalHeight());
-    d->rect  = QRect(w/2-d->preview.width()/2, h/2-d->preview.height()/2,
-                     d->preview.width(), d->preview.height());
+    d->pixmap = new QPixmap(w, h);
+    d->image  = QRect(0, 0, d->iface->originalWidth(), d->iface->originalHeight());
+    d->rect   = QRect(w/2-d->preview.width()/2, h/2-d->preview.height()/2,
+                      d->preview.width(), d->preview.height());
 
     updatePixmap();
     setGoldenGuideTypes(true, false, false, false, false, false);
 }
 
-Digikam::ImageIface* ImageSelectionWidget::imageIface()
+ImageIface* ImageSelectionWidget::imageIface()
 {
     return d->iface;
 }
@@ -222,19 +223,19 @@ void ImageSelectionWidget::resizeEvent(QResizeEvent *e)
     int height      = d->iface->previewHeight();
     bool sixteenBit = d->iface->previewSixteenBit();
     bool hasAlpha   = d->iface->previewHasAlpha();
-    d->preview      = Digikam::DImg(width, height, sixteenBit, hasAlpha, data);
-    delete [] data;
+    d->preview      = DImg(width, height, sixteenBit, hasAlpha, data);
+    d->preview.setIccProfile( d->iface->getOriginalImg()->getIccProfile() );
     d->preview.convertToEightBit();
+    delete [] data;
 
     d->pixmap = new QPixmap(w, h);
-
     d->rect   = QRect(w/2-d->preview.width()/2, h/2-d->preview.height()/2,
                       d->preview.width(), d->preview.height());
 
     // Drawing the gray overlay
     {
-        Digikam::DImg image = d->preview.copy();
-        uchar* ptr          = image.bits();
+        DImg image = d->preview.copy();
+        uchar* ptr = image.bits();
         uchar  r, g, b;
 
         int xlow  = d->rect.left();
@@ -262,7 +263,7 @@ void ImageSelectionWidget::resizeEvent(QResizeEvent *e)
             }
         }
         d->grayOverLay   = image.convertToPixmap();
-        d->previewPixmap = d->preview.convertToPixmap();
+        d->previewPixmap = d->iface->convertToPixmap(d->preview);
     }
 
     updatePixmap();
@@ -906,22 +907,16 @@ void ImageSelectionWidget::drawGoldenMean(QPainter& p, const QRect& R1,
 void ImageSelectionWidget::updatePixmap()
 {
     // Updated local selection region.
-    d->localRegionSelection.setTopLeft(
-            convertPoint(d->regionSelection.topLeft(), false));
-    d->localRegionSelection.setBottomRight(
-            convertPoint(d->regionSelection.bottomRight(), false));
+    d->localRegionSelection.setTopLeft(convertPoint(d->regionSelection.topLeft(), false));
+    d->localRegionSelection.setBottomRight(convertPoint(d->regionSelection.bottomRight(), false));
 
     // Updated dragging corners region.
-    d->localTopLeftCorner.setRect(d->localRegionSelection.left(),
-                                  d->localRegionSelection.top(), 8, 8);
-    d->localBottomLeftCorner.setRect(d->localRegionSelection.left(),
-                                     d->localRegionSelection.bottom() - 7, 8, 8);
-    d->localTopRightCorner.setRect(d->localRegionSelection.right() - 7,
-                                   d->localRegionSelection.top(), 8, 8);
-    d->localBottomRightCorner.setRect(d->localRegionSelection.right() - 7,
-                                      d->localRegionSelection.bottom() - 7, 8, 8);
+    d->localTopLeftCorner.setRect(d->localRegionSelection.left(),          d->localRegionSelection.top(),        8, 8);
+    d->localBottomLeftCorner.setRect(d->localRegionSelection.left(),       d->localRegionSelection.bottom() - 7, 8, 8);
+    d->localTopRightCorner.setRect(d->localRegionSelection.right() - 7,    d->localRegionSelection.top(),        8, 8);
+    d->localBottomRightCorner.setRect(d->localRegionSelection.right() - 7, d->localRegionSelection.bottom() - 7, 8, 8);
 
-    // Drawing background and image.
+    // Drawing background.
     d->pixmap->fill(palette().color(QPalette::Background));
 
     if (d->preview.isNull())
@@ -933,13 +928,13 @@ void ImageSelectionWidget::updatePixmap()
     int dh = d->localRegionSelection.height();
 
     QPainter p(d->pixmap);
-
     p.drawPixmap(d->rect.x(), d->rect.y(), d->grayOverLay);
 
     // Stop here if no selection to draw
     if (d->regionSelection.isEmpty() || !d->isDrawingSelection)
         return;
 
+    // Now draw the image.
     p.drawPixmap(d->localRegionSelection.left(), d->localRegionSelection.top(), d->previewPixmap,
                  sx, sy, dw, dh);
 
