@@ -26,6 +26,10 @@
 #ifndef DIMG_H
 #define DIMG_H
 
+// KExiv2 includes
+
+#include <libkexiv2/kexiv2data.h>
+
 // Qt includes
 
 #include <QtCore/QByteArray>
@@ -38,7 +42,6 @@
 // Local includes
 
 #include "digikam_export.h"
-#include "dmetadatadata.h"
 #include "dshareddata.h"
 #include "drawdecoding.h"
 #include "dcolor.h"
@@ -50,6 +53,8 @@ class QString;
 namespace Digikam
 {
 
+typedef KExiv2Iface::KExiv2Data KExiv2Data;
+
 class ExposureSettingsContainer;
 class DImgPrivate;
 class IccTransform;
@@ -366,12 +371,12 @@ public:
     /** QImage wrapper methods
      */
     QImage     copyQImage();
-    QImage     copyQImage(QRect rect);
+    QImage     copyQImage(const QRect& rect);
     QImage     copyQImage(int x, int y, int w, int h);
 
     /** Crop image to the specified region
      */
-    void       crop(QRect rect);
+    void       crop(const QRect& rect);
     void       crop(int x, int y, int w, int h);
 
     /** Set width and height of this image, smoothScale it to the given size
