@@ -44,11 +44,12 @@
 #include <kglobalsettings.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
-#include <ktabwidget.h>
+#include <kiconloader.h>
 
 // LibKDcraw includes
 
 #include <libkdcraw/rexpanderbox.h>
+#include "rexpanderboxexclusive.h"
 #include <libkdcraw/rnuminput.h>
 
 // Local includes
@@ -63,7 +64,7 @@ using namespace KDcrawIface;
 namespace Digikam
 {
 
-class BWSepiaSettingsPriv
+class BWSepiaSettings::BWSepiaSettingsPriv
 {
 
 public:
@@ -117,118 +118,121 @@ public:
     PreviewList*               bwFilm;
     PreviewList*               bwTone;
 
-    KTabWidget*                tab;
+    RExpanderBoxExclusive*     tab;
 
     KDcrawIface::RIntNumInput* cInput;
     KDcrawIface::RIntNumInput* strengthInput;
 
     CurvesBox*                 curvesBox;
+
+    DImg                       thumbImage;
 };
 
 BWSepiaSettings::BWSepiaSettings(QWidget* parent, DImg* img)
                : QWidget(parent),
                  d(new BWSepiaSettingsPriv)
 {
-    DImg thumbImage = img->smoothScale(128, 128, Qt::KeepAspectRatio);
+    if (!img->isNull()) d->thumbImage = img->smoothScale(128, 128, Qt::KeepAspectRatio);
+    else                d->thumbImage = DImg(DesktopIcon("image-x-generic", 128).toImage());
 
     QGridLayout* grid = new QGridLayout(parent);
 
-    d->tab = new KTabWidget(this);
+    d->tab = new RExpanderBoxExclusive(this);
 
     PreviewListItem* item = 0;
     d->bwFilm             = new PreviewList;
     int type              = BWSepiaContainer::BWGeneric;
 
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18nc("generic black and white film", "Generic"), type);
-    item->setWhatsThis(0, i18n("<b>Generic</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18nc("generic black and white film", "Generic"), type);
+    item->setWhatsThis(i18n("<b>Generic</b>:"
                                "<p>Simulate a generic black and white film.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Agfa 200X"), type);
-    item->setWhatsThis(0, i18n("<b>Agfa 200X</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Agfa 200X"), type);
+    item->setWhatsThis(i18n("<b>Agfa 200X</b>:"
                                "<p>Simulate the Agfa 200X black and white film at 200 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Agfa Pan 25"), type);
-    item->setWhatsThis(0, i18n("<b>Agfa Pan 25</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Agfa Pan 25"), type);
+    item->setWhatsThis(i18n("<b>Agfa Pan 25</b>:"
                                "<p>Simulate the Agfa Pan black and white film at 25 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Agfa Pan 100"), type);
-    item->setWhatsThis(0, i18n("<b>Agfa Pan 100</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Agfa Pan 100"), type);
+    item->setWhatsThis(i18n("<b>Agfa Pan 100</b>:"
                                "<p>Simulate the Agfa Pan black and white film at 100 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Agfa Pan 400"), type);
-    item->setWhatsThis(0, i18n("<b>Agfa Pan 400</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Agfa Pan 400"), type);
+    item->setWhatsThis(i18n("<b>Agfa Pan 400</b>:"
                                "<p>Simulate the Agfa Pan black and white film at 400 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford Delta 100"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford Delta 100</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford Delta 100"), type);
+    item->setWhatsThis(i18n("<b>Ilford Delta 100</b>:"
                                "<p>Simulate the Ilford Delta black and white film at 100 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford Delta 400"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford Delta 400</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford Delta 400"), type);
+    item->setWhatsThis(i18n("<b>Ilford Delta 400</b>:"
                                "<p>Simulate the Ilford Delta black and white film at 400 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford Delta 400 Pro 3200"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford Delta 400 Pro 3200</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford Delta 400 Pro 3200"), type);
+    item->setWhatsThis(i18n("<b>Ilford Delta 400 Pro 3200</b>:"
                                "<p>Simulate the Ilford Delta 400 Pro black and white film at 3200 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford FP4 Plus"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford FP4 Plus</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford FP4 Plus"), type);
+    item->setWhatsThis(i18n("<b>Ilford FP4 Plus</b>:"
                                "<p>Simulate the Ilford FP4 Plus black and white film at 125 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford HP5 Plus"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford HP5 Plus</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford HP5 Plus"), type);
+    item->setWhatsThis(i18n("<b>Ilford HP5 Plus</b>:"
                                "<p>Simulate the Ilford HP5 Plus black and white film at 400 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford PanF Plus"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford PanF Plus</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford PanF Plus"), type);
+    item->setWhatsThis(i18n("<b>Ilford PanF Plus</b>:"
                                "<p>Simulate the Ilford PanF Plus black and white film at 50 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford XP2 Super"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford XP2 Super</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford XP2 Super"), type);
+    item->setWhatsThis(i18n("<b>Ilford XP2 Super</b>:"
                                "<p>Simulate the Ilford XP2 Super black and white film at 400 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Kodak Tmax 100"), type);
-    item->setWhatsThis(0, i18n("<b>Kodak Tmax 100</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Kodak Tmax 100"), type);
+    item->setWhatsThis(i18n("<b>Kodak Tmax 100</b>:"
                                "<p>Simulate the Kodak Tmax black and white film at 100 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Kodak Tmax 400"), type);
-    item->setWhatsThis(0, i18n("<b>Kodak Tmax 400</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Kodak Tmax 400"), type);
+    item->setWhatsThis(i18n("<b>Kodak Tmax 400</b>:"
                                "<p>Simulate the Kodak Tmax black and white film at 400 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Kodak TriX"), type);
-    item->setWhatsThis(0, i18n("<b>Kodak TriX</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Kodak TriX"), type);
+    item->setWhatsThis(i18n("<b>Kodak TriX</b>:"
                                "<p>Simulate the Kodak TriX black and white film at 400 ISO.</p>"));
 
     // -------------------------------------------------------------
 
     type = BWSepiaContainer::BWIlfordSFX200;
 
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford SPX 200"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford SPX 200</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford SPX 200"), type);
+    item->setWhatsThis(i18n("<b>Ilford SPX 200</b>:"
                                "<p>Simulate the Ilford SPX infrared film at 200 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford SPX 400"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford SPX 400</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford SPX 400"), type);
+    item->setWhatsThis(i18n("<b>Ilford SPX 400</b>:"
                                "<p>Simulate the Ilford SPX infrared film at 400 ISO.</p>"));
 
     ++type;
-    item = d->bwFilm->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford SPX 800"), type);
-    item->setWhatsThis(0, i18n("<b>Ilford SPX 800</b>:"
+    item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Ilford SPX 800"), type);
+    item->setWhatsThis(i18n("<b>Ilford SPX 800</b>:"
                                "<p>Simulate the Ilford SPX infrared film at 800 ISO.</p>"));
 
     // -------------------------------------------------------------
@@ -238,41 +242,41 @@ BWSepiaSettings::BWSepiaSettings(QWidget* parent, DImg* img)
     d->bwFilters      = new PreviewList(vbox);
 
     type = BWSepiaContainer::BWNoFilter;
-    item = d->bwFilters->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("No Lens Filter"), type);
-    item->setWhatsThis(0, i18n("<b>No Lens Filter</b>:"
+    item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("No Lens Filter"), type);
+    item->setWhatsThis(i18n("<b>No Lens Filter</b>:"
                                "<p>Do not apply a lens filter when rendering the image.</p>"));
 
     ++type;
-    item = d->bwFilters->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Green Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Green Filter</b>:"
+    item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Green Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Green Filter</b>:"
                                "<p>Simulate black and white film exposure using a green filter. "
                                "This is useful for all scenic shoots, especially "
                                "portraits photographed against the sky.</p>"));
 
     ++type;
-    item = d->bwFilters->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Orange Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Orange Filter</b>:"
+    item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Orange Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Orange Filter</b>:"
                                "<p>Simulate black and white film exposure using an orange filter. "
                                "This will enhance landscapes, marine scenes and aerial "
                                "photography.</p>"));
 
     ++type;
-    item = d->bwFilters->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Red Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Red Filter</b>:"
+    item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Red Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Red Filter</b>:"
                                "<p>Simulate black and white film exposure using a red filter. "
                                "This creates dramatic sky effects, and simulates moonlight scenes "
                                "in the daytime.</p>"));
 
     ++type;
-    item = d->bwFilters->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Yellow Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Yellow Filter</b>:"
+    item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Yellow Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Yellow Filter</b>:"
                                "<p>Simulate black and white film exposure using a yellow filter. "
                                "This has the most natural tonal correction, and improves contrast. Ideal for "
                                "landscapes.</p>"));
 
     ++type;
-    item = d->bwFilters->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Yellow-Green Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Yellow-Green Filter</b>:"
+    item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Yellow-Green Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Yellow-Green Filter</b>:"
                                "<p>Simulate black and white film exposure using a yellow-green filter. "
                                "A yellow-green filter is highly effective for outdoor portraits because "
                                "red is rendered dark while green appears lighter. Great for correcting skin tones, "
@@ -280,8 +284,8 @@ BWSepiaSettings::BWSepiaSettings(QWidget* parent, DImg* img)
                                "This filter is highly effective for indoor portraits under tungsten lighting.</p>"));
 
     ++type;
-    item = d->bwFilters->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Blue Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Blue Filter</b>:"
+    item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Blue Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Blue Filter</b>:"
                                "<p>Simulate black and white film exposure using a blue filter. "
                                "This accentuates haze and fog. Used for dye transfer and contrast effects.</p>"));
 
@@ -302,82 +306,87 @@ BWSepiaSettings::BWSepiaSettings(QWidget* parent, DImg* img)
     d->bwTone = new PreviewList;
 
     type = BWSepiaContainer::BWNoTone;
-    item = d->bwTone->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("No Tone Filter"), type);
-    item->setWhatsThis(0, i18n("<b>No Tone Filter</b>:"
+    item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("No Tone Filter"), type);
+    item->setWhatsThis(i18n("<b>No Tone Filter</b>:"
                                "<p>Do not apply a tone filter to the image.</p>"));
 
     ++type;
-    item = d->bwTone->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Sepia Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Sepia Tone</b>:"
+    item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Sepia Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Sepia Tone</b>:"
                                "<p>Gives a warm highlight and mid-tone while adding a bit of coolness to "
                                "the shadows - very similar to the process of bleaching a print and "
                                "re-developing in a sepia toner.</p>"));
 
     ++type;
-    item = d->bwTone->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Brown Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Brown Tone</b>:"
+    item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Brown Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Brown Tone</b>:"
                                "<p>This filter is more neutral than the Sepia Tone "
                                "filter.</p>"));
 
     ++type;
-    item = d->bwTone->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Cold Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Cold Tone</b>:"
+    item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Cold Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Cold Tone</b>:"
                                "<p>Start subtly and replicate printing on a cold tone black and white "
                                "paper such as a bromide enlarging "
                                "paper.</p>"));
 
     ++type;
-    item = d->bwTone->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Selenium Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Selenium Tone</b>:"
+    item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Selenium Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Selenium Tone</b>:"
                                "<p>This effect replicates traditional selenium chemical toning done "
                                "in the darkroom.</p>"));
 
     ++type;
-    item = d->bwTone->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Platinum Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with Platinum Tone</b>:"
+    item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Platinum Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with Platinum Tone</b>:"
                                "<p>This effect replicates traditional platinum chemical toning done "
                                "in the darkroom.</p>"));
 
     ++type;
-    item = d->bwTone->addItem(new BWSepiaFilter(&thumbImage, 0, BWSepiaContainer(type)), i18n("Green Filter"), type);
-    item->setWhatsThis(0, i18n("<b>Black & White with greenish tint</b>:"
+    item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type)), i18n("Green Filter"), type);
+    item->setWhatsThis(i18n("<b>Black & White with greenish tint</b>:"
                                "<p>This effect is also known as Verdante.</p>"));
 
     // -------------------------------------------------------------
 
-    QWidget* curveBox = new QWidget();
+    QWidget* lumBox = new QWidget();
     // NOTE: add a method to be able to use curves widget without image data as simple curve editor.
-    if (!img->isNull()) d->curvesBox = new CurvesBox(256, 192, img->bits(), img->width(), img->height(), img->sixteenBit(), curveBox);
-    else                d->curvesBox = new CurvesBox(256, 192, (uchar*)"\x00\x00\x00\x00\x00\x00\x00\x00", 1, 1, true, curveBox);
+    if (!img->isNull()) d->curvesBox = new CurvesBox(256, 192, img->bits(), img->width(), img->height(), img->sixteenBit(), lumBox);
+    else                d->curvesBox = new CurvesBox(256, 192, (uchar*)"\x00\x00\x00\x00\x00\x00\x00\x00", 1, 1, true, lumBox);
     d->curvesBox->enableCurveTypes(true);
     d->curvesBox->enableResetButton(true);
-    d->curvesBox->setWhatsThis( i18n("This is the curve adjustment of the image luminosity"));
+    d->curvesBox->setWhatsThis(i18n("This is the curve adjustment of the image luminosity"));
 
     // -------------------------------------------------------------
 
-    d->cInput = new RIntNumInput(curveBox);
+    d->cInput = new RIntNumInput(lumBox);
     d->cInput->input()->setLabel(i18n("Contrast:"), Qt::AlignLeft | Qt::AlignVCenter);
     d->cInput->setRange(-100, 100, 1);
     d->cInput->setSliderEnabled(true);
     d->cInput->setDefaultValue(0);
     d->cInput->setWhatsThis(i18n("Set here the contrast adjustment of the image."));
 
-    QGridLayout* gridTab2 = new QGridLayout();
+    QGridLayout* gridTab2 = new QGridLayout(lumBox);
     gridTab2->addWidget(d->curvesBox, 0, 0, 1, 1);
     gridTab2->addWidget(d->cInput,    1, 0, 1, 1);
     gridTab2->setRowStretch(2, 10);
     gridTab2->setMargin(KDialog::spacingHint());
     gridTab2->setSpacing(0);
-    curveBox->setLayout(gridTab2);
 
     // -------------------------------------------------------------
 
-    d->tab->insertTab(BWSepiaSettingsPriv::FilmTab,       d->bwFilm, i18n("Film"));
-    d->tab->insertTab(BWSepiaSettingsPriv::BWFiltersTab,  vbox,      i18n("Lens Filters"));
-    d->tab->insertTab(BWSepiaSettingsPriv::ToneTab,       d->bwTone, i18n("Tone"));
-    d->tab->insertTab(BWSepiaSettingsPriv::LuminosityTab, curveBox,  i18n("Lightness"));
+    // Some new icons may be needed : a film roll, a lens filter and ?
+    d->tab->addItem(d->bwFilm, SmallIcon("filmgrain"),
+                    i18n("Film"), QString("Film"), true);
+    d->tab->addItem(vbox, SmallIcon("lensautofix"),
+                    i18n("Lens Filters"), QString("Lens Filters"), false);
+    d->tab->addItem(d->bwTone, SmallIcon("fill-color"),
+                    i18n("Tone"), QString("Tone"), false);
+    d->tab->addItem(lumBox, SmallIcon("adjustcurves"),
+                    i18n("Luminosity"), QString("Luminosity"), false);
+    d->tab->addStretch();
 
-    grid->addWidget(d->tab, 0, 0, 1, 5);
+    grid->addWidget(d->tab, 0, 0, 1, 10);
     grid->setRowStretch(0, 10);
     grid->setMargin(KDialog::spacingHint());
     grid->setSpacing(KDialog::spacingHint());
@@ -491,7 +500,7 @@ void BWSepiaSettings::readSettings(KConfigGroup& group)
     BWSepiaContainer prm;
     BWSepiaContainer defaultPrm = defaultSettings();
 
-    d->tab->setCurrentIndex(group.readEntry(d->configSettingsTabEntry, 0));
+    d->tab->readSettings();
 
     prm.filmType        = group.readEntry(d->configBWFilmEntry,             defaultPrm.filmType);
     prm.filterType      = group.readEntry(d->configBWFilterEntry,           defaultPrm.filterType);
@@ -501,7 +510,7 @@ void BWSepiaSettings::readSettings(KConfigGroup& group)
 
     d->curvesBox->readCurveSettings(group, d->configCurveEntry);
     prm.curvesPrm.lumCurveVals = d->curvesBox->curves()->getCurveValues(LuminosityChannel);
-    
+
     setSettings(prm);
 }
 
@@ -509,7 +518,8 @@ void BWSepiaSettings::writeSettings(KConfigGroup& group)
 {
     BWSepiaContainer prm = settings();
 
-    group.writeEntry(d->configSettingsTabEntry,        d->tab->currentIndex());
+    d->tab->writeSettings();
+
     group.writeEntry(d->configBWFilmEntry,             prm.filmType);
     group.writeEntry(d->configBWFilterEntry,           prm.filterType);
     group.writeEntry(d->configBWToneEntry,             prm.toneType);
