@@ -7,7 +7,7 @@
  * Description : DImg image loader interface
  *
  * Copyright (C) 2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2005-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -61,12 +61,12 @@ public:
 
     void setLoadFlags(LoadFlags flags);
 
-    virtual bool load(const QString& filePath, DImgLoaderObserver *observer) = 0;
-    virtual bool save(const QString& filePath, DImgLoaderObserver *observer) = 0;
+    virtual bool load(const QString& filePath, DImgLoaderObserver* observer) = 0;
+    virtual bool save(const QString& filePath, DImgLoaderObserver* observer) = 0;
 
-    virtual bool hasAlpha()   const = 0;
-    virtual bool sixteenBit() const = 0;
-    virtual bool isReadOnly() const = 0;
+    virtual bool hasAlpha()      const = 0;
+    virtual bool sixteenBit()    const = 0;
+    virtual bool isReadOnly()    const = 0;
     virtual bool hasLoadedData() const;
 
     static QByteArray uniqueHash(const QString& filePath, const DImg& img, bool loadMetadata);
@@ -85,18 +85,18 @@ protected:
     int                     imageBitsDepth();
     int                     imageBytesDepth();
 
-    QMap<int, QByteArray>&  imageMetaData();
     void                    imageSetIccProfile(const IccProfile& profile);
     QVariant                imageGetAttribute(const QString& key);
     void                    imageSetAttribute(const QString& key, const QVariant& value);
 
     QMap<QString, QString>& imageEmbeddedText();
+    KExiv2Data              imageMetadata();
     QString                 imageGetEmbbededText(const QString& key);
     void                    imageSetEmbbededText(const QString& key, const QString& text);
 
     virtual bool            readMetadata(const QString& filePath, DImg::FORMAT ff);
     virtual bool            saveMetadata(const QString& filePath);
-    virtual int             granularity(DImgLoaderObserver *observer, int total, float progressSlice = 1.0);
+    virtual int             granularity(DImgLoaderObserver* observer, int total, float progressSlice = 1.0);
 
     bool                    checkExifWorkingColorSpace();
 
@@ -105,7 +105,7 @@ protected:
 
 protected:
 
-    DImg                   *m_image;
+    DImg*                   m_image;
     LoadFlags               m_loadFlags;
 
 private:
