@@ -74,7 +74,6 @@ public:
         histogram     = 0;
         histoSegments = 0;
         valid         = false;
-        runningFlag   = true;
     }
 
     /** The histogram data.*/
@@ -82,30 +81,27 @@ public:
     bool                  valid;
 
     /** Image information.*/
-    uchar*                imageData;
+    const uchar*         imageData;
     uint                  imageWidth;
     uint                  imageHeight;
 
     /** Numbers of histogram segments depending of image bytes depth*/
     int                   histoSegments;
-
-    /** Used to stop thread during calculations.*/
-    bool                  runningFlag;
 };
 
 ImageHistogram::ImageHistogram(const DImg& image, QObject *parent)
-              : QThread(parent), d(new ImageHistogramPriv)
+              : DynamicThread(parent), d(new ImageHistogramPriv)
 {
     setup(image.bits(), image.width(), image.height(), image.sixteenBit());
 }
 
-ImageHistogram::ImageHistogram(uchar *i_data, uint i_w, uint i_h, bool i_sixteenBits, QObject *parent)
-              : QThread(parent), d(new ImageHistogramPriv)
+ImageHistogram::ImageHistogram(const uchar *i_data, uint i_w, uint i_h, bool i_sixteenBits, QObject *parent)
+              : DynamicThread(parent), d(new ImageHistogramPriv)
 {
     setup(i_data, i_w, i_h, i_sixteenBits);
 }
 
-void ImageHistogram::setup(uchar *i_data, uint i_w, uint i_h, bool i_sixteenBits)
+void ImageHistogram::setup(const uchar *i_data, uint i_w, uint i_h, bool i_sixteenBits)
 {
     d->imageData     = i_data;
     d->imageWidth    = i_w;
@@ -154,7 +150,7 @@ void ImageHistogram::calculateInThread()
 
 void ImageHistogram::stopCalculation()
 {
-    d->runningFlag = false;
+    stop();
     wait();
 }
 
@@ -204,7 +200,7 @@ void ImageHistogram::calculate()
         unsigned short  blue, green, red, alpha;
         unsigned short *data = (unsigned short*)d->imageData;
 
-        for (i = 0 ; (i < d->imageHeight*d->imageWidth*4) && d->runningFlag ; i+=4)
+        for (i = 0 ; (i < d->imageHeight*d->imageWidth*4) && runningFlag() ; i+=4)
         {
             blue  = data[ i ];
             green = data[i+1];
@@ -227,9 +223,9 @@ void ImageHistogram::calculate()
     else                                  // 8 bits images.
     {
         uchar blue, green, red, alpha;
-        uchar *data = d->imageData;
+        const uchar *data = d->imageData;
 
-        for (i = 0 ; (i < d->imageHeight*d->imageWidth*4) && d->runningFlag ; i+=4)
+        for (i = 0 ; (i < d->imageHeight*d->imageWidth*4) && runningFlag() ; i+=4)
         {
             blue  = data[ i ];
             green = data[i+1];
@@ -250,7 +246,7 @@ void ImageHistogram::calculate()
         }
     }
 
-    if (d->runningFlag)
+    if (runningFlag())
     {
         d->valid = true;
         emit calculationFinished(this, true);
