@@ -26,6 +26,7 @@
 
 // KDE includes
 
+#include <kdebug.h>
 #include <klocale.h>
 #include <kglobal.h>
 
@@ -93,13 +94,23 @@ QVariant AbstractAlbumModel::albumData(Album *a, int role) const
             return a->title();
         case Qt::DecorationRole:
             // reimplement in subclasses
-            return decorationRole(a);
+            return decorationRoleData(a);
+        case AlbumTitleRole:
+            return a->title();
         case AlbumTypeRole:
             return a->type();
         case AlbumPointerRole:
             return QVariant::fromValue(a);
+        case AlbumIdRole:
+            return a->id();
+        case AlbumGlobalIdRole:
+            return a->globalID();
+        case AlbumSortRole:
+            // reimplement in subclass
+            return sortRoleData(a);
+        default:
+            return QVariant();
     }
-    return QVariant();
 }
 
 QVariant AbstractAlbumModel::headerData(int section, Qt::Orientation orientation, int role) const
@@ -164,7 +175,7 @@ bool AbstractAlbumModel::hasChildren(const QModelIndex& parent) const
 
 QModelIndex AbstractAlbumModel::index(int row, int column, const QModelIndex& parent) const
 {
-    if (column != 0)
+    if (column != 0 || row < 0)
         return QModelIndex();
 
     if (parent.isValid())
@@ -286,6 +297,11 @@ Album *AbstractAlbumModel::albumForIndex(const QModelIndex& index) const
     return static_cast<Album*>(index.internalPointer());
 }
 
+Album *AbstractAlbumModel::retrieveAlbum(const QModelIndex& index)
+{
+    return index.data(AbstractAlbumModel::AlbumPointerRole).value<Album*>();
+}
+
 Album *AbstractAlbumModel::rootAlbum() const
 {
     return d->rootAlbum;
@@ -296,16 +312,26 @@ QModelIndex AbstractAlbumModel::rootAlbumIndex() const
     return indexForAlbum(d->rootAlbum);
 }
 
+AbstractAlbumModel::RootAlbumBehavior AbstractAlbumModel::rootAlbumBehavior() const
+{
+    return d->rootBehavior;
+}
+
 Album::Type AbstractAlbumModel::albumType() const
 {
     return d->type;
 }
 
-QVariant AbstractAlbumModel::decorationRole(Album *) const
+QVariant AbstractAlbumModel::decorationRoleData(Album *) const
 {
     return QVariant();
 }
 
+QVariant AbstractAlbumModel::sortRoleData(Album *a) const
+{
+    return a->title();
+}
+
 QString AbstractAlbumModel::columnHeader() const
 {
     return i18n("Album");
@@ -331,6 +357,12 @@ void AbstractAlbumModel::slotAlbumAboutToBeAdded(Album *album, Album *parent, Al
     if (!filterAlbum(album))
         return;
 
+    if (album->isRoot() && d->rootBehavior == IgnoreRootAlbum)
+    {
+        d->rootAlbum = album;
+        return;
+    }
+
     // start inserting operation
     int row = prev ? d->findIndexAsChild(prev)+1 : 0;
     QModelIndex parentIndex = indexForAlbum(parent);
@@ -350,7 +382,6 @@ void AbstractAlbumModel::slotAlbumAdded(Album *album)
 {
     if (d->addingAlbum == album)
     {
-
         bool isRoot = d->addingAlbum == d->rootAlbum;
         d->addingAlbum = 0;
         endInsertRows();
@@ -364,11 +395,18 @@ void AbstractAlbumModel::slotAlbumAboutToBeDeleted(Album *album)
     if (!filterAlbum(album))
         return;
 
+    if (album->isRoot() && d->rootBehavior == IgnoreRootAlbum)
+    {
+        albumCleared(album);
+        d->rootAlbum = 0;
+        return;
+    }
+
     // begin removing operation
     int row = d->findIndexAsChild(album);
     QModelIndex parent = indexForAlbum(album->parent());
-    albumCleared(album);
     beginRemoveRows(parent, row, row);
+    albumCleared(album);
 
     // store album for slotAlbumHasBeenDeleted
     d->removingAlbum = album;
@@ -392,6 +430,8 @@ void AbstractAlbumModel::slotAlbumsCleared()
 
 void AbstractAlbumModel::slotAlbumIconChanged(Album* album)
 {
+    if (!filterAlbum(album))
+        return;
     QModelIndex index = indexForAlbum(album);
     emit dataChanged(index, index);
 }
@@ -485,6 +525,9 @@ AbstractCountingAlbumModel::AbstractCountingAlbumModel(Album::Type albumType, Al
                                                        QObject *parent)
                            : AbstractSpecificAlbumModel(albumType, rootAlbum, rootBehavior, parent)
 {
+    connect(AlbumManager::instance(), SIGNAL(signalAlbumMoved(Album*)),
+            this, SLOT(slotAlbumMoved(Album*)));
+
     m_showCount = false;
 }
 
@@ -531,7 +574,16 @@ void AbstractCountingAlbumModel::setCountMap(const QMap<int, int>& idCountMap)
 void AbstractCountingAlbumModel::updateCount(Album *album)
 {
     if (!album)
+    {
         return;
+    }
+
+    // if the model does not contain the album, do nothing.
+    QModelIndex index = indexForAlbum(album);
+    if (!index.isValid())
+    {
+        return;
+    }
 
     QHash<int, int>::iterator includeIt = m_countHashReady.find(album->id());
     bool changed = false;
@@ -565,7 +617,6 @@ void AbstractCountingAlbumModel::updateCount(Album *album)
     // notify views
     if (changed)
     {
-        QModelIndex index = indexForAlbum(album);
         emit dataChanged(index, index);
     }
 }
@@ -573,7 +624,16 @@ void AbstractCountingAlbumModel::updateCount(Album *album)
 void AbstractCountingAlbumModel::setCount(Album *album, int count)
 {
     if (!album)
+    {
         return;
+    }
+
+    // if the model does not contain the album, do nothing.
+    QModelIndex index = indexForAlbum(album);
+    if (!index.isValid())
+    {
+        return;
+    }
 
     QHash<int, int>::iterator includeIt = m_countHashReady.find(album->id());
     bool changed = false;
@@ -593,7 +653,6 @@ void AbstractCountingAlbumModel::setCount(Album *album, int count)
     // notify views
     if (changed)
     {
-        QModelIndex index = indexForAlbum(album);
         emit dataChanged(index, index);
     }
 }
@@ -609,6 +668,18 @@ QVariant AbstractCountingAlbumModel::albumData(Album *album, int role) const
     return AbstractSpecificAlbumModel::albumData(album, role);
 }
 
+int AbstractCountingAlbumModel::albumCount(Album *album) const
+{
+    QHash<int, int>::const_iterator it = m_countHashReady.constFind(album->id());
+    if (it != m_countHashReady.constEnd())
+    {
+        return it.value();
+    }
+
+    return -1;
+
+}
+
 QString AbstractCountingAlbumModel::albumName(Album *album) const
 {
     return album->title();
@@ -616,9 +687,12 @@ QString AbstractCountingAlbumModel::albumName(Album *album) const
 
 void AbstractCountingAlbumModel::albumCleared(Album *album)
 {
-    m_countMap.remove(album->id());
-    m_countHashReady.remove(album->id());
-    m_includeChildrenAlbums.remove(album->id());
+    if (!AlbumManager::instance()->isMovingAlbum(album))
+    {
+        m_countMap.remove(album->id());
+        m_countHashReady.remove(album->id());
+        m_includeChildrenAlbums.remove(album->id());
+    }
 }
 
 void AbstractCountingAlbumModel::allAlbumsCleared()
@@ -628,6 +702,12 @@ void AbstractCountingAlbumModel::allAlbumsCleared()
     m_includeChildrenAlbums.clear();
 }
 
+void AbstractCountingAlbumModel::slotAlbumMoved(Album *)
+{
+    // need to update counts of all parents
+    setCountMap(m_countMap);
+}
+
 // ------------------------------------------------------------------
 
 AbstractCheckableAlbumModel::AbstractCheckableAlbumModel(Album::Type albumType, Album *rootAlbum,
@@ -636,6 +716,7 @@ AbstractCheckableAlbumModel::AbstractCheckableAlbumModel(Album::Type albumType,
                            : AbstractCountingAlbumModel(albumType, rootAlbum, rootBehavior, parent)
 {
     m_extraFlags = 0;
+    m_rootIsCheckable = true;
 }
 
 void AbstractCheckableAlbumModel::setCheckable(bool isCheckable)
@@ -654,6 +735,19 @@ bool AbstractCheckableAlbumModel::isCheckable() const
     return m_extraFlags & Qt::ItemIsUserCheckable;
 }
 
+void AbstractCheckableAlbumModel::setRootCheckable(bool isCheckable)
+{
+    m_rootIsCheckable = isCheckable;
+    Album *root = rootAlbum();
+    if (!m_rootIsCheckable && root)
+        setChecked(root, false);
+}
+
+bool AbstractCheckableAlbumModel::rootIsCheckable() const
+{
+    return m_rootIsCheckable && isCheckable();
+}
+
 void AbstractCheckableAlbumModel::setTristate(bool isTristate)
 {
     if (isTristate)
@@ -698,7 +792,7 @@ QList<Album *> AbstractCheckableAlbumModel::checkedAlbums() const
     return m_checkedAlbums.keys(Qt::Checked);
 }
 
-void AbstractCheckableAlbumModel::resetCheckedAlbums()
+void AbstractCheckableAlbumModel::resetAllCheckedAlbums()
 {
     QList<Album *> oldChecked = m_checkedAlbums.keys();
     m_checkedAlbums.clear();
@@ -710,11 +804,83 @@ void AbstractCheckableAlbumModel::resetCheckedAlbums()
     }
 }
 
+void AbstractCheckableAlbumModel::setDataForChildren(QModelIndex &parent, const QVariant& value, int role)
+{
+    setData(parent, value, role);
+    for (int row = 0; row < rowCount(parent); ++row)
+    {
+        QModelIndex childIndex = index(row, 0, parent);
+        setDataForChildren(childIndex, value, role);
+    }
+}
+
+void AbstractCheckableAlbumModel::resetCheckedAlbums(QModelIndex parent)
+{
+
+    if (parent == rootAlbumIndex())
+    {
+        resetAllCheckedAlbums();
+        return;
+    }
+
+    setDataForChildren(parent, Qt::Unchecked, Qt::CheckStateRole);
+}
+
+void AbstractCheckableAlbumModel::setDataForParents(QModelIndex &child, const QVariant& value, int role)
+{
+    QModelIndex current = child;
+    while (current.isValid() && current != rootAlbumIndex()) {
+        setData(current, value, role);
+        current = parent(current);
+    }
+}
+
+void AbstractCheckableAlbumModel::resetCheckedParentAlbums(QModelIndex &child)
+{
+    setDataForParents(child, Qt::Unchecked, Qt::CheckStateRole);
+}
+
+void AbstractCheckableAlbumModel::checkAllParentAlbums(QModelIndex &child)
+{
+    setDataForParents(child, Qt::Checked, Qt::CheckStateRole);
+}
+
+void AbstractCheckableAlbumModel::checkAllAlbums(QModelIndex parent)
+{
+    setDataForChildren(parent, Qt::Checked, Qt::CheckStateRole);
+}
+
+void AbstractCheckableAlbumModel::invertCheckedAlbums(QModelIndex parent)
+{
+    Album *album = albumForIndex(parent);
+    if (album)
+    {
+        toggleChecked(album);
+    }
+    for (int row = 0; row < rowCount(parent); ++row)
+    {
+        invertCheckedAlbums(index(row, 0, parent));
+    }
+}
+
+void AbstractCheckableAlbumModel::setCheckStateForChildren(Album *album, Qt::CheckState state)
+{
+    QModelIndex index = indexForAlbum(album);
+    setDataForChildren(index, state, Qt::CheckStateRole);
+}
+
+void AbstractCheckableAlbumModel::setCheckStateForParents(Album *album, Qt::CheckState state)
+{
+    QModelIndex index = indexForAlbum(album);
+    setDataForParents(index, state, Qt::CheckStateRole);
+}
+
 QVariant AbstractCheckableAlbumModel::albumData(Album *a, int role) const
 {
     if (role == Qt::CheckStateRole)
     {
-        if (m_extraFlags & Qt::ItemIsUserCheckable)
+        if (m_extraFlags & Qt::ItemIsUserCheckable
+            && (!a->isRoot() || m_rootIsCheckable))
         {
             // with Qt::Unchecked as default, albums not in the hash (initially all)
             // are simply regarded as unchecked
@@ -727,7 +893,14 @@ QVariant AbstractCheckableAlbumModel::albumData(Album *a, int role) const
 
 Qt::ItemFlags AbstractCheckableAlbumModel::flags(const QModelIndex& index) const
 {
-    return AbstractCountingAlbumModel::flags(index) | m_extraFlags;
+    Qt::ItemFlags extraFlags = m_extraFlags;
+    if (!m_rootIsCheckable)
+    {
+        QModelIndex root = rootAlbumIndex();
+        if (root.isValid() && index == root)
+            extraFlags &= ~Qt::ItemIsUserCheckable;
+    }
+    return AbstractCountingAlbumModel::flags(index) | extraFlags;
 }
 
 bool AbstractCheckableAlbumModel::setData(const QModelIndex& index, const QVariant& value, int role)
@@ -738,6 +911,7 @@ bool AbstractCheckableAlbumModel::setData(const QModelIndex& index, const QVaria
         Album *album = albumForIndex(index);
         if (!album)
             return false;
+        //kDebug() << "Updating check state for album" << album->title() << "to" << value;
         m_checkedAlbums.insert(album, state);
         emit dataChanged(index, index);
         emit checkStateChanged(album, state);
@@ -749,7 +923,9 @@ bool AbstractCheckableAlbumModel::setData(const QModelIndex& index, const QVaria
 
 void AbstractCheckableAlbumModel::albumCleared(Album *album)
 {
-    m_checkedAlbums.remove(album);
+    // preserve check state if album is only being moved
+    if (!AlbumManager::instance()->isMovingAlbum(album))
+        m_checkedAlbums.remove(album);
     AbstractCountingAlbumModel::albumCleared(album);
 }
 
