@@ -6,7 +6,7 @@
  * Date        : 2009-06-29
  * Description : metadata template viewer.
  *
- * Copyright (C) 2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -28,9 +28,11 @@
 
 #include <QString>
 
-// Local includes
+// LibKDcraw includes
 
-#include "rexpanderbox.h"
+#include <libkdcraw/rexpanderbox.h>
+
+using namespace KDcrawIface;
 
 namespace Digikam
 {
