@@ -71,7 +71,9 @@ public:
         // Wait for loading and saving tasks, stop and remove preloading tasks
         TerminationPolicyTerminatePreloading,
         // Wait for all pending tasks
-        TerminationPolicyWait
+        TerminationPolicyWait,
+        // Stop all pending tasks
+        TerminationPolicyTerminateAll
     };
 
     enum LoadingTaskFilter
@@ -118,6 +120,8 @@ public:
 
 protected:
 
+    void shutdownThread();
+
     void load(const LoadingDescription& description, LoadingMode loadingMode,
               LoadingPolicy policy = LoadingPolicyAppend, AccessMode mode = AccessModeReadWrite);
     void loadPreview(const LoadingDescription& description);
