@@ -6,12 +6,12 @@
  * Date        : 2004-11-22
  * Description : stand alone digiKam image editor GUI
  *
+ * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Copyright (C) 2005-2006 by Tom Albers <tomalbers@kde.nl>
  * Copyright (C) 2008 by Arnd Baecker <arnd dot baecker at web dot de>
- * Copyright (C) 2004-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2009 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -116,6 +116,7 @@ extern "C"
 #include "thumbnailloadthread.h"
 #include "thumbnailsize.h"
 #include "uifilevalidator.h"
+#include "knotificationwrapper.h"
 
 namespace ShowFoto
 {
@@ -281,7 +282,6 @@ ShowFoto::ShowFoto(const KUrl::List& urlList)
     else
     {
         toggleNavigation(1);
-        toggleActions(true);
     }
 }
 
@@ -577,8 +577,6 @@ void ShowFoto::slotOpenFile()
             new Digikam::ThumbBarItem(d->thumbBar, *it);
             d->lastOpenedDirectory=(*it);
         }
-
-        toggleActions(true);
     }
 }
 
@@ -604,12 +602,12 @@ void ShowFoto::slotOpenUrl(const KUrl& url)
     // TODO : add preload here like in ImageWindow::slotLoadCurrent() ???
 }
 
-Digikam::ThumbBarDock *ShowFoto::thumbBar() const
+Digikam::ThumbBarDock* ShowFoto::thumbBar() const
 {
     return d->thumbBarDock;
 }
 
-Digikam::Sidebar *ShowFoto::rightSideBar() const
+Digikam::Sidebar* ShowFoto::rightSideBar() const
 {
     return (dynamic_cast<Digikam::Sidebar*>(d->rightSideBar));
 }
@@ -727,7 +725,6 @@ void ShowFoto::slotOpenFolder(const KUrl& url)
     emit signalNoCurrentItem();
     d->currentItem = 0;
     openFolder(url);
-    toggleActions(true);
     toggleNavigation(1);
 }
 
@@ -933,6 +930,15 @@ void ShowFoto::toggleNavigation(int index)
     }
 }
 
+void ShowFoto::slotPrepareToLoad()
+{
+    Digikam::EditorWindow::slotPrepareToLoad();
+
+    // Here we enable specific actions on showfoto.
+    d->openFilesInFolderAction->setEnabled(true);
+    d->fileOpenAction->setEnabled(true);
+}
+
 void ShowFoto::slotLoadingStarted(const QString& filename)
 {
     Digikam::EditorWindow::slotLoadingStarted(filename);
@@ -973,6 +979,10 @@ void ShowFoto::saveIsComplete()
 {
     Digikam::LoadingCacheInterface::putImage(m_savingContext->destinationURL.toLocalFile(), m_canvas->currentImage());
     d->thumbBar->invalidateThumb(d->currentItem);
+
+    // Pop-up a message to bring user when save is done.
+    Digikam::KNotificationWrapper("editorsavefilecompleted", i18n("save file is completed..."),
+                                  this, windowTitle());
 }
 
 void ShowFoto::saveAsIsComplete()
@@ -993,6 +1003,10 @@ void ShowFoto::saveAsIsComplete()
     d->thumbBar->blockSignals(false);
     d->currentItem = foundItem;
     slotUpdateItemInfo();
+
+    // Pop-up a message to bring user when save is done.
+    Digikam::KNotificationWrapper("editorsavefilecompleted", i18n("save file is completed..."),
+                                  this, windowTitle());
 }
 
 KUrl ShowFoto::saveDestinationUrl()
