@@ -44,6 +44,7 @@
 #include "casemodifier.h"
 #include "defaultvaluemodifier.h"
 #include "rangemodifier.h"
+#include "removedoublesmodifier.h"
 #include "replacemodifier.h"
 #include "trimmedmodifier.h"
 #include "uniquemodifier.h"
@@ -55,14 +56,11 @@ class ParserPriv
 {
 public:
 
-    ParserPriv() :
-        counter(0)
+    ParserPriv()
     {}
 
-    ParseSettings globalSettings;
-    OptionsList   options;
-    ModifierList  modifiers;
-    int           counter;
+    OptionsList            options;
+    ModifierList           modifiers;
 };
 
 // --------------------------------------------------------
@@ -86,13 +84,10 @@ Parser::Parser()
     registerModifier(new CaseModifier());
     registerModifier(new TrimmedModifier());
     registerModifier(new UniqueModifier());
+    registerModifier(new RemoveDoublesModifier());
     registerModifier(new DefaultValueModifier());
     registerModifier(new ReplaceModifier());
     registerModifier(new RangeModifier());
-
-    // --------------------------------------------------------
-
-    init(ParseSettings());
 }
 
 Parser::~Parser()
@@ -112,15 +107,15 @@ Parser::~Parser()
     delete d;
 }
 
-void Parser::init(const ParseSettings& settings)
-{
-    d->globalSettings = settings;
-    d->counter  = 1;
-}
+//void Parser::init(const ParseSettings& settings)
+//{
+//    d->globalSettings = settings;
+////    d->counter  = 1;
+//}
 
 void Parser::reset()
 {
-    init(ParseSettings());
+//    init(ParseSettings());
     foreach (Option* option, d->options)
     {
         option->reset();
@@ -218,8 +213,8 @@ QString Parser::parse(ParseSettings& settings)
 
     ParseResults results;
 
-    settings.startIndex   = d->globalSettings.startIndex;
-    settings.currentIndex = d->counter++;
+//    settings.startIndex   = d->globalSettings.startIndex;
+//    settings.currentIndex = d->counter++;
 
     foreach (Option* option, d->options)
     {
