@@ -6,7 +6,7 @@
  * Date        : 2008-06-17
  * Description : Find Duplicates tree-view search album item.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,11 +26,9 @@
 // Qt includes
 
 #include <QPainter>
-#include <QTreeWidget>
 
 // KDE includes
 
-
 #include <klocale.h>
 #include <kstringhandler.h>
 
@@ -42,16 +40,30 @@
 namespace Digikam
 {
 
-FindDuplicatesAlbumItem::FindDuplicatesAlbumItem(QTreeWidget* parent, SAlbum* album)
-                       : TreeFolderItem(parent, QString())
+class FindDuplicatesAlbumItem::FindDuplicatesAlbumItemPriv
 {
-    m_album = album;
-    if (m_album)
-    {
-        m_refImgInfo = ImageInfo(m_album->title().toLongLong());
-        setText(0, m_refImgInfo.name());
 
-        SearchXmlReader reader(m_album->query());
+public:
+
+    FindDuplicatesAlbumItemPriv()
+    {
+        album = 0;
+    }
+
+    SAlbum*   album;
+    ImageInfo refImgInfo;
+};
+
+FindDuplicatesAlbumItem::FindDuplicatesAlbumItem(QTreeWidget* parent, SAlbum* album)
+                       : QTreeWidgetItem(parent), d(new FindDuplicatesAlbumItemPriv)
+{
+    d->album = album;
+    if (d->album)
+    {
+        d->refImgInfo = ImageInfo(d->album->title().toLongLong());
+        setText(0, d->refImgInfo.name());
+
+        SearchXmlReader reader(d->album->query());
         reader.readToFirstField();
         QList<int> list;
         list << reader.valueToIntList();
@@ -61,6 +73,7 @@ FindDuplicatesAlbumItem::FindDuplicatesAlbumItem(QTreeWidget* parent, SAlbum* al
 
 FindDuplicatesAlbumItem::~FindDuplicatesAlbumItem()
 {
+    delete d;
 }
 
 void FindDuplicatesAlbumItem::setThumb(const QPixmap& pix)
@@ -71,17 +84,26 @@ void FindDuplicatesAlbumItem::setThumb(const QPixmap& pix)
     QPainter p(&pixmap);
     p.drawPixmap((pixmap.width()/2)  - (pix.width()/2),
                  (pixmap.height()/2) - (pix.height()/2), pix);
-    setIcon(0, QIcon(pixmap));
+
+    QIcon icon = QIcon(pixmap);
+    //  We make sure the preview icon stays the same regardless of the role
+    icon.addPixmap(pixmap, QIcon::Selected, QIcon::On);
+    icon.addPixmap(pixmap, QIcon::Selected, QIcon::Off);
+    icon.addPixmap(pixmap, QIcon::Active,   QIcon::On);
+    icon.addPixmap(pixmap, QIcon::Active,   QIcon::Off);
+    icon.addPixmap(pixmap, QIcon::Normal,   QIcon::On);
+    icon.addPixmap(pixmap, QIcon::Normal,   QIcon::Off);
+    setIcon(0, icon);
 }
 
 SAlbum* FindDuplicatesAlbumItem::album() const
 {
-    return m_album;
+    return d->album;
 }
 
 KUrl FindDuplicatesAlbumItem::refUrl() const
 {
-    return m_refImgInfo.fileUrl();
+    return d->refImgInfo.fileUrl();
 }
 
 bool FindDuplicatesAlbumItem::operator<(const QTreeWidgetItem& other) const
@@ -90,6 +112,7 @@ bool FindDuplicatesAlbumItem::operator<(const QTreeWidgetItem& other) const
     int result = KStringHandler::naturalCompare(text(column), other.text(column));
     if (result < 0)
         return true;
+
     return false;
 }
 
