@@ -56,7 +56,6 @@
 
 // Local includes
 
-#include "bcgmodifier.h"
 #include "colorcorrectiondlg.h"
 #include "undomanager.h"
 #include "undoaction.h"
@@ -363,7 +362,12 @@ void DImgInterface::slotImageLoaded(const LoadingDescription& loadingDescription
         if (d->image.detectedFormat() == DImg::RAW)
             d->rotatedOrFlipped = true;
         else if (d->exifOrient)
-             exifRotate(d->filename);
+        {
+            // Do not rotate twice if already rotated, e.g. for full size preview.
+            QVariant attribute(d->image.attribute("exifRotated"));
+            if (!attribute.isValid() || !attribute.toBool())
+                exifRotate(d->filename);
+        }
 
         updateColorManagement();
     }
@@ -587,24 +591,7 @@ bool DImgInterface::hasChangesToSave()
 void DImgInterface::readMetadataFromFile(const QString& file)
 {
     DMetadata meta(file);
-
-    //TODO: code is essentially the same as DImgLoader::readMetadata,
-    //      put both in a common place.
-    if (!meta.getComments().isNull())
-        d->image.setComments(meta.getComments());
-
-#if KEXIV2_VERSION >= 0x010000
-    if (!meta.getExifEncoded().isNull())
-        d->image.setExif(meta.getExifEncoded());
-#else
-    if (!meta.getExif().isNull())
-        d->image.setExif(meta.getExif());
-#endif
-
-    if (!meta.getIptc().isNull())
-        d->image.setIptc(meta.getIptc());
-    if (!meta.getXmp().isNull())
-        d->image.setXmp(meta.getXmp());
+    d->image.setMetadata(meta.data());
 }
 
 void DImgInterface::clearUndoManager()
@@ -1021,19 +1008,9 @@ IccProfile DImgInterface::getEmbeddedICC()
     return d->image.getIccProfile();
 }
 
-QByteArray DImgInterface::getExif()
+KExiv2Data DImgInterface::getMetadata()
 {
-    return d->image.getExif();
-}
-
-QByteArray DImgInterface::getIptc()
-{
-    return d->image.getIptc();
-}
-
-QByteArray DImgInterface::getXmp()
-{
-    return d->image.getXmp();
+    return d->image.getMetadata();
 }
 
 QString DImgInterface::getImageFilePath()
